@@ -6,6 +6,7 @@ from __future__ import absolute_import
 from wavefront_api_client.api.access_policy_api import AccessPolicyApi
 from wavefront_api_client.api.account__user_and_service_account_api import AccountUserAndServiceAccountApi
 from wavefront_api_client.api.alert_api import AlertApi
+from wavefront_api_client.api.alert_analytics_api import AlertAnalyticsApi
 from wavefront_api_client.api.api_token_api import ApiTokenApi
 from wavefront_api_client.api.cloud_integration_api import CloudIntegrationApi
 from wavefront_api_client.api.dashboard_api import DashboardApi
@@ -24,12 +25,19 @@ from wavefront_api_client.api.monitored_service_api import MonitoredServiceApi
 from wavefront_api_client.api.notificant_api import NotificantApi
 from wavefront_api_client.api.proxy_api import ProxyApi
 from wavefront_api_client.api.query_api import QueryApi
+from wavefront_api_client.api.recent_app_map_search_api import RecentAppMapSearchApi
+from wavefront_api_client.api.recent_traces_search_api import RecentTracesSearchApi
 from wavefront_api_client.api.role_api import RoleApi
+from wavefront_api_client.api.saved_app_map_search_api import SavedAppMapSearchApi
+from wavefront_api_client.api.saved_app_map_search_group_api import SavedAppMapSearchGroupApi
 from wavefront_api_client.api.saved_search_api import SavedSearchApi
+from wavefront_api_client.api.saved_traces_search_api import SavedTracesSearchApi
+from wavefront_api_client.api.saved_traces_search_group_api import SavedTracesSearchGroupApi
 from wavefront_api_client.api.search_api import SearchApi
 from wavefront_api_client.api.source_api import SourceApi
 from wavefront_api_client.api.span_sampling_policy_api import SpanSamplingPolicyApi
 from wavefront_api_client.api.usage_api import UsageApi
 from wavefront_api_client.api.user_api import UserApi
 from wavefront_api_client.api.user_group_api import UserGroupApi
+from wavefront_api_client.api.wavefront_api import WavefrontApi
 from wavefront_api_client.api.webhook_api import WebhookApi
